==> libkleo-16.04.0.tar.xz: libkleo-16.04.0/src/tests/gnupgviewer.h <==
/*
    gnupgviewer.h

    This file is part of libkleopatra's test suite.
    Copyright (c) 2004 Klarälvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEO_TESTS_GNUPGVIEWER_H__
#define __KLEO_TESTS_GNUPGVIEWER_H__

#include <qtextedit.h>
#include <QString>
#include <QProcess>
namespace Kleo
{
class GnuPGProcessBase;
}
class QStringList;

class GnuPGViewer : public QTextEdit
{
    Q_OBJECT
public:
    GnuPGViewer(QWidget *parent = Q_NULLPTR);
    ~GnuPGViewer();

    void setProcess(Kleo::GnuPGProcessBase *process);

private Q_SLOTS:
    void slotStdout();
    void slotStderr();
    void slotStatus(Kleo::GnuPGProcessBase *, const QString &, const QStringList &);
    void slotProcessExited(int, QProcess::ExitStatus);

private:
    Kleo::GnuPGProcessBase *mProcess;
    QString mLastStdout, mLastStderr, mLastStatus;
};

#endif // __KLEO_TESTS_GNUPGVIEWER_H__

==> libkleo-17.08.0.tar.xz: libkleo-17.08.0/src/tests/gnupgviewer.h <==
/*
    gnupgviewer.h

    This file is part of libkleopatra's test suite.
    Copyright (c) 2004 Klarälvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEO_TESTS_GNUPGVIEWER_H__
#define __KLEO_TESTS_GNUPGVIEWER_H__

#include <qtextedit.h>
#include <QString>
#include <QProcess>
namespace Kleo
{
class GnuPGProcessBase;
}
class QStringList;

class GnuPGViewer : public QTextEdit
{
    Q_OBJECT
public:
    GnuPGViewer(QWidget *parent = nullptr);
    ~GnuPGViewer();

    void setProcess(Kleo::GnuPGProcessBase *process);

private Q_SLOTS:
    void slotStdout();
    void slotStderr();
    void slotStatus(Kleo::GnuPGProcessBase *, const QString &, const QStringList &);
    void slotProcessExited(int, QProcess::ExitStatus);

private:
    Kleo::GnuPGProcessBase *mProcess;
    QString mLastStdout, mLastStderr, mLastStatus;
};

#endif // __KLEO_TESTS_GNUPGVIEWER_H__
